<?php

namespace Drupal\confirmation\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBundleBase;

/**
 * Defines the Confirmation type configuration entity.
 *
 * @ConfigEntityType(
 *   id = "confirmation_type",
 *   label = @Translation("Confirmation type"),
 *   label_collection = @Translation("Confirmation types"),
 *   label_singular = @Translation("Confirmation type"),
 *   label_plural = @Translation("Confirmations types"),
 *   label_count = @PluralTranslation(
 *     singular = "@count Confirmations type",
 *     plural = "@count Confirmations types",
 *   ),
 *   handlers = {
 *     "form" = {
 *       "add" = "Drupal\confirmation\Entity\Form\ConfirmationTypeForm",
 *       "edit" = "Drupal\confirmation\Entity\Form\ConfirmationTypeForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *     },
 *     "list_builder" = "Drupal\confirmation\Entity\List\ConfirmationTypeListBuilder",
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     }
 *   },
 *   admin_permission = "administer confirmation types",
 *   bundle_of = "confirmation",
 *   config_prefix = "confirmation_type",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "add-form" = "/admin/structure/confirmation_types/add",
 *     "edit-form" = "/admin/structure/confirmation_types/manage/{confirmation_type}",
 *     "delete-form" = "/admin/structure/confirmation_types/manage/{confirmation_type}/delete",
 *     "collection" = "/admin/structure/confirmation_types"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "uuid",
 *   }
 * )
 */
class ConfirmationType extends ConfigEntityBundleBase {

  /**
   * The machine name of this Confirmation type.
   *
   * @var string
   */
  protected $id;

  /**
   * The human-readable name of the Confirmation type.
   *
   * @var string
   */
  protected $label;

}
